aboutsummaryrefslogtreecommitdiffhomepage
path: root/builtin.cpp
diff options
context:
space:
mode:
authorGravatar ridiculousfish <corydoras@ridiculousfish.com>2013-07-21 14:04:06 -0700
committerGravatar ridiculousfish <corydoras@ridiculousfish.com>2013-07-21 14:04:06 -0700
commit551d2dfebdbc0d2308d98ffaa7f044eb5a25b547 (patch)
tree1bb3145fa646fb9f95a06df41cdbe4d97280ef8d /builtin.cpp
parent93f27666db09107561c2500c7b5e2047dbbc72fb (diff)
parentf9c2a77c67754324f3036ec79501c6131d19562b (diff)
Merge branch 'master' into ast_templates
Conflicts: fish_tests.cpp
Diffstat (limited to 'builtin.cpp')
-rw-r--r--builtin.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/builtin.cpp b/builtin.cpp
index 331f9630..3b40be3c 100644
--- a/builtin.cpp
+++ b/builtin.cpp
@@ -1660,7 +1660,7 @@ static int builtin_echo(parser_t &parser, wchar_t **argv)
wc = L'\b';
break;
case L'e':
- wc = L'\e';
+ wc = L'\x1B';
break;
case L'f':
wc = L'\f';
@@ -2372,8 +2372,9 @@ static int builtin_read(parser_t &parser, wchar_t **argv)
reader_set_highlight_function(&highlight_shell);
reader_set_test_function(&reader_shell_test);
}
/* No autosuggestions in builtin_read */
reader_set_allow_autosuggesting(false);
+ reader_set_expand_abbreviations(false);
reader_set_exit_on_interrupt(true);
reader_set_buffer(commandline, wcslen(commandline));
@@ -2372,8 +2372,9 @@ static int builtin_read(parser_t &parser, wchar_t **argv)
reader_set_test_function(&reader_shell_test);
}
- /* No autosuggestions in builtin_read */
+ /* No autosuggestions or abbreviations in builtin_read */
reader_set_allow_autosuggesting(false);